@@ -39,7 +39,7 @@ def mamba_install(prefix, specs, args, env, *_, **kwargs):
         channel_urls.extend(context.channels)
     _channel_priority_map = prioritize_channels(channel_urls)
 
-    index = get_index(tuple(_channel_priority_map.keys()))
+    index = get_index(tuple(_channel_priority_map.keys()), prepend=False)
 
     channel_json = []
 
@@ -74,8 +74,11 @@ def mamba_install(prefix, specs, args, env, *_, **kwargs):
     if not success:
         print(solver.problems_to_str())
 
-    transaction = api.Transaction(solver)
-    to_link, to_unlink = transaction.to_conda()
+    package_cache = api.MultiPackageCache(context.pkgs_dirs)
+    transaction = api.Transaction(solver, package_cache)
+    mmb_specs, to_link, to_unlink = transaction.to_conda()
+
+    specs_to_add = [MatchSpec(m) for m in mmb_specs[0]]
 
     to_link_records, to_unlink_records = [], []
 
@@ -94,15 +97,15 @@ def mamba_install(prefix, specs, args, env, *_, **kwargs):
 
     unlink_precs, link_precs = diff_for_unlink_link_precs(prefix,
                                                           final_precs=IndexedSet(PrefixGraph(final_precs).graph),
-                                                          specs_to_add=specs,
+                                                          specs_to_add=specs_to_add,
                                                           force_reinstall=context.force_reinstall)
 
     pref_setup = PrefixSetup(
         target_prefix = prefix,
         unlink_precs  = unlink_precs,
         link_precs    = link_precs,
-        remove_specs  = [],
-        update_specs  = specs,
+        remove_specs  = (),
+        update_specs  = specs_to_add,
         neutered_specs = ()
     )
 
